@@ -22,11 +22,10 @@ but sometimes parameters will be overriden to ensure an output is produced.
 class NoDataFoundException(Exception):
     pass
 
-
-class TranslateQuery(pydantic.BaseModel):
-    input_text: str = Field(description="text to translate")
-    source_language: cloudlanguagetools.languages.CommonLanguage = Field(description="language to translate from")
-    target_language: cloudlanguagetools.languages.CommonLanguage = Field(description="language to translate to")
+class TranslateLookupQuery(pydantic.BaseModel):
+    input_text: str = Field(description="text to translate or lookup in the dictionary")
+    source_language: cloudlanguagetools.languages.CommonLanguage = Field(description="language of the text to translate or lookup in dictionary")
+    target_language: cloudlanguagetools.languages.CommonLanguage = Field(description="language to translate to, or language of dictionary definition")
     service: Optional[cloudlanguagetools.constants.Service] = Field(default=None, description='service to use for translation')
 
 class TransliterateQuery(pydantic.BaseModel):
@@ -34,12 +33,6 @@ class TransliterateQuery(pydantic.BaseModel):
     language: cloudlanguagetools.languages.CommonLanguage = Field(description="language the text is in")
     service: Optional[cloudlanguagetools.constants.Service] = Field(default=None, description='service to use for transliteration')
 
-class DictionaryLookup(pydantic.BaseModel):
-    input_text: str = Field(description="text to lookup in the dictionary")
-    source_language: cloudlanguagetools.languages.CommonLanguage = Field(description="language of the text to look up")
-    target_language: cloudlanguagetools.languages.CommonLanguage = Field(description="language for the dictionary definition")
-    service: Optional[cloudlanguagetools.constants.Service] = Field(default=None, description='service to use for dictionary lookup')
-
 class AudioQuery(pydantic.BaseModel):
     input_text: str = Field(description="text to pronounce / generate audio")
     language: cloudlanguagetools.languages.CommonLanguage = Field(description="language the text is in")
@@ -134,7 +127,7 @@ class ChatAPI():
 
         return transliteration_option
 
-    def translate(self, query: TranslateQuery):
+    def translate(self, query: TranslateLookupQuery):
         logger.info(f'translating {query.input_text} from {query.source_language} to {query.target_language}')
 
         source_language = cloudlanguagetools.languages.Language[query.source_language.name]
@@ -151,7 +144,7 @@ class ChatAPI():
         return translated_text
 
 
-    def transliterate(self, query: TranslateQuery):
+    def transliterate(self, query: TransliterateQuery):
         language = cloudlanguagetools.languages.Language[query.language.name]
         transliteration_option = self.select_transliteration_option(query.service, language)
         transliterated_text = self.manager.get_transliteration(
@@ -161,7 +154,19 @@ class ChatAPI():
         )
         return transliterated_text
 
-    def dictionary_lookup(self, query: DictionaryLookup):
+    def translate_or_lookup(self, query: TranslateLookupQuery):
+        logger.info(f'translation or dictionary lookup: {query}')
+
+        try:
+            # try dictionary lookup as a first attempt
+            result = self.dictionary_lookup(query)
+            return result
+        except cloudlanguagetools.errors.NotFoundError as e:
+            # if dictionary lookup fails, try translation
+            result = self.translate(query)
+            return result
+
+    def dictionary_lookup(self, query: TranslateLookupQuery):
         logger.info(f'dictionary lookup {query}')
         source_language = cloudlanguagetools.languages.Language[query.source_language.name]
         target_language = cloudlanguagetools.languages.Language[query.target_language.name]
@@ -198,15 +203,12 @@ class ChatAPI():
         dictionary_option = final_candidates[0]
         logger.debug(f'Using dictionary option {pprint.pformat(dictionary_option.json_obj())}')
 
-        try:
-            dictionary_result = self.manager.get_dictionary_lookup(
-                query.input_text,
-                service,
-                dictionary_option.get_lookup_key()
-            )
-            result = ' / '.join(dictionary_result)
-        except cloudlanguagetools.errors.NotFoundError as e:
-            result = f'No dictionary lookup results found for {query.input_text}'
+        dictionary_result = self.manager.get_dictionary_lookup(
+            query.input_text,
+            service,
+            dictionary_option.get_lookup_key()
+        )
+        result = ' / '.join(dictionary_result)
         return result
         
 
