@@ -1,5 +1,4 @@
 import enum
-from strenum import StrEnum
 
 class Language(enum.Enum):
     af = ("Afrikaans")
@@ -256,14 +255,15 @@ class AudioLanguage(enum.Enum):
     az_AZ = (Language.az, "Azerbaijani (Azerbaijan)")
     ba_RU = (Language.ba, "Bashkir (Russia)")
 
-    bg_BG = (Language.bg, "Bulgarian")
+    be_BY = (Language.be, "Belarusian (Belarus)")
+    bg_BG = (Language.bg, "Bulgarian (Bulgaria)")
     bn_BD = (Language.bn, "Bangla (Bangladesh)")
     bn_IN = (Language.bn, "Bengali (India)")
     bs_BA = (Language.bs, "Bosnian (Bosnia and Herzegovina)")
     ca_ES = (Language.ca, "Catalan")
     cs_CZ = (Language.cs, "Czech")
     cy_GB = (Language.cy, "Welsh")
-    da_DK = (Language.da, "Danish")
+    da_DK = (Language.da, "Danish (Denmark)")
     fo_FO = (Language.fo, "Faroese (Faroe Islands)")
     de_AT = (Language.de, "German (Austria)")
     de_CH = (Language.de, "German (Switzerland)")
@@ -311,7 +311,7 @@ class AudioLanguage(enum.Enum):
     es_UY = (Language.es, "Spanish (Uruguay)")
     es_VE = (Language.es, "Spanish (Venezuela)")
 
-    et_EE = (Language.et, "Estonian")
+    et_EE = (Language.et, "Estonian (Estonia)")
     eu_ES = (Language.eu, "Basque (Basque Country)")
     fi_FI = (Language.fi, "Finnish")
     fil_PH = (Language.tl, "Filipino (Philippines)")
@@ -349,10 +349,10 @@ class AudioLanguage(enum.Enum):
     ms_MY = (Language.ms, "Malay")
     mt_MT = (Language.mt, "Maltese (Malta)")
     my_MM = (Language.my, "Burmese (Myanmar [Burma])")
-    nb_NO = (Language.nb, "Norwegian")
+    nb_NO = (Language.nb, "Norwegian (Norway)")
     ne_NP = (Language.ne, "Nepali (Nepal)")
     nl_BE = (Language.nl, "Dutch (Belgium)")
-    nl_NL = (Language.nl, "Dutch")
+    nl_NL = (Language.nl, "Dutch (Netherlands)")
     pa_IN = (Language.pa, "Punjabi (India)")
     pl_PL = (Language.pl, "Polish")
     ps_AF = (Language.ps, "Pashto (Afghanistan)")
@@ -395,6 +395,7 @@ class AudioLanguage(enum.Enum):
     zh_CN_shaanxi = (Language.zh_cn, 'Chinese (Zhongyuan Mandarin Shaanxi, Simplified)')
     zh_CN_shandong = (Language.zh_cn, 'Chinese (Jilu Mandarin, Simplified)')
     zh_CN_sichuan = (Language.zh_cn, 'Chinese (Southwestern Mandarin, Simplified)')
+    zh_CN_guangxi = (Language.zh_cn, 'Chinese (Guangxi Accent Mandarin, Simplified)')
 
     fa_IR = (Language.fa, "Persian (Iran)")
     zu_ZA = (Language.zu, "Zulu (South Africa)")
